@@ -26,7 +26,7 @@ typedef struct secret_buffer_charset secret_buffer_charset;
  * range of characters 0..255 through `s/$patern//g` and building the bitmap
  * from the result.
  */
-extern secret_buffer_charset *secret_buffer_charset_from_regexpref(SV *ref);
+extern secret_buffer_charset * secret_buffer_charset_from_regexpref(SV *ref);
 
 /* Test whether the charset contains an 8-bit byte.
  * This relies solely on the bitmap.
@@ -114,7 +114,7 @@ extern bool secret_buffer_transcode(secret_buffer_parse *src, secret_buffer_pars
  * ref to a new SV if you want to keep the object.
  * Always returns a secret_buffer, or croaks on failure.
  */
-extern secret_buffer* secret_buffer_new(size_t capacity, SV **ref_out);
+extern secret_buffer * secret_buffer_new(size_t capacity, SV **ref_out);
 
 /* Given a SV which you expect to be a reference to a blessed object with SecretBuffer
  * magic, return the secret_buffer struct pointer.
@@ -128,7 +128,7 @@ extern secret_buffer* secret_buffer_new(size_t capacity, SV **ref_out);
 #define SECRET_BUFFER_MAGIC_AUTOCREATE 1
 #define SECRET_BUFFER_MAGIC_OR_DIE     2
 #define SECRET_BUFFER_MAGIC_UNDEF_OK   4
-extern secret_buffer* secret_buffer_from_magic(SV *ref, int flags);
+extern secret_buffer * secret_buffer_from_magic(SV *ref, int flags);
 
 /* Reallocate (or free) the buffer of secret_buffer, fully erasing it before deallocation.
  * If capacity is zero, the buffer will be freed and 'data' pointer set to NULL.
@@ -148,10 +148,23 @@ extern void secret_buffer_alloc_at_least(secret_buffer *buf, size_t min_capacity
  */
 extern void secret_buffer_set_len(secret_buffer *buf, size_t new_len);
 
-/* Overwrite the buffer with the contents of the SV, taking into account
- * whether it might be a scalar-ref, SecretBuffer, or SecretBuffer::Span.
+/* Overwrite a span of the buffer with the supplied bytes.  The buffer length is updated
+ * to match.  Offset and length are unsigned, so they do not support the "negative from end of
+ * buffer" convention common to Perl.
  */
-extern void secret_buffer_assign_sv(secret_buffer *buf, SV *src);
+extern void secret_buffer_splice(secret_buffer *buf, size_t ofs, size_t len,
+   const char *replacement, size_t replacement_len);
+/* Convenience to combine secret_buffer_SvPVbyte with secret_buffer_splice */
+extern void secret_buffer_splice_sv(secret_buffer *buf, size_t ofs, size_t len, SV *replacement);
+
+/* Given an SV, perform SvPVbyte on it, but make special cases for SecretBuffer,
+ * SecretBuffer::Span, or un-blessed scalar-refs.  Note that the return value has all of the
+ * caveats of SvPVbyte (like maybe returning a temporary buffer) and also all the caveats of
+ * returning a pointer into a SecretBuffer, namely that if you alter that SecretBuffer
+ * elsewhere the pointer is no longer valid.  It may even return a pointer to static data.
+ * The string is *NOT* terminated with a NUL byte, and you must pass 'len_out'.
+ */
+extern const char * secret_buffer_SvPVbyte(SV *thing, STRLEN *len_out);
 
 /* Append N bytes of cryptographic quality random bytes to the end of the buffer.
  * This may block if your entropy pool is low.
@@ -216,7 +229,7 @@ X extern void secret_buffer_result_cancel(SV *promise_ref); */
  * aware of SecretBuffer and can't be fed the secret any other way.  Beware that the secret
  * may "get loose" unintentionally when allowing Perl to read the value as an SV.
  */
-extern SV* secret_buffer_get_stringify_sv(secret_buffer *buf);
+extern SV * secret_buffer_get_stringify_sv(secret_buffer *buf);
 
 /* This is just exposing the wipe function of this library for general use.
  * It will be one of `explicit_bzero`, `SecureZeroMemory`, or just `bzero` which should
@@ -224,6 +237,4 @@ extern SV* secret_buffer_get_stringify_sv(secret_buffer *buf);
  */
 extern void secret_buffer_wipe(char *buf, size_t len);
 
-#include "SecretBufferManualLinkage.h"
-
 #endif /* CRYPT_SECRETBUFFER_H */
